@@ -260,6 +260,9 @@ class Subscription(object):
 
         return False
 
+    def _updateId(self, new_id):
+        self.__info.id = new_id
+
     def _updateProtocol0(self, sub_msg, length):
         if sub_msg:
             counter = 0
