@@ -531,10 +531,21 @@ class SetString(unittest.TestCase):
         parameter_tree = motorcortex.ParameterTree()
         # Open request and subscribe connection
         req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex.MessageTypes(), parameter_tree,
-                                       certificate="mcx.crt.pem", timeout_ms=1000,
+                                       certificate="mcx.cert.pem", timeout_ms=1000,
                                        login="root", password="secret")
         res = req.setParameter("root/Control/dummyChar", "Hallo robot!")
-        res.get();
+        res.get()
+
+
+class SetParameterWithOffset(unittest.TestCase):
+    def test(self):
+        parameter_tree = motorcortex.ParameterTree()
+        # Open request and subscribe connection
+        req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex.MessageTypes(), parameter_tree,
+                                       certificate="mcx.cert.pem", timeout_ms=1000,
+                                       login="root", password="secret")
+        res = req.setParameter("root/Control/hostInJointTrajectory", [6, 5])
+        res.get()
 
 
 if __name__ == '__main__':
